==> QSTK-0.2.4.tar.gz: QSTK-0.2.4/README.md <==
QSTK
====

QuantSoftware Toolkit 2.0

License
=====

The QuantSoftware ToolKit (QSTK) is released under the New BSD License as follows:

Copyright (c) 2011, 2012, Georgia Tech Research Corporation (GTRC) All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 

 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer
  in the documentation and/or other materials provided with the distribution. 

 3) Neither the name of the Georgia Tech Research Corporation nor the names of its contributors may be used to endorse or promote
  products derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE GEORGIA TECH RESEARCH CORPORATION BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE. 

Dependencies
====
"numpy >= 1.6.1",
"scipy >= 0.9.0",
"matplotlib >= 1.1.0",
"pandas==0.7.3",
"python-dateutil >= 1.5",
"cvxopt >= 1.1.3",
"scikit-learn >= 0.11"

Author
====

Dr. Tucker Balch 

Sourabh Bajaj

John Cornwell

Website
====

www.wiki.quantsoftware.org

==> QSTK-0.2.5.tar.gz: QSTK-0.2.5/README.md <==
QSTK
====

QuantSoftware Toolkit 0.2.5

Website
====

www.wiki.quantsoftware.org

License
=====

The QuantSoftware ToolKit (QSTK) is released under the New BSD License as follows:

Copyright (c) 2011, 2012, Georgia Tech Research Corporation (GTRC) All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 

 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer
  in the documentation and/or other materials provided with the distribution. 

 3) Neither the name of the Georgia Tech Research Corporation nor the names of its contributors may be used to endorse or promote
  products derived from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE GEORGIA TECH RESEARCH CORPORATION BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, 
OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE. 

Dependencies
====
numpy >= 1.6.1,
scipy >= 0.9.0,
matplotlib >= 1.1.0,
pandas==0.7.3,
python-dateutil >= 1.5,
cvxopt >= 1.1.3,
scikit-learn >= 0.11

Author
====

Prof. Tucker Balch 

Sourabh Bajaj

John Cornwell
